@@ -17,6 +17,8 @@ import logging
 import queue
 import sys
 import typing
+from collections import namedtuple
+from statistics import mean, median
 from types import (
     BuiltinFunctionType,
     FunctionType,
@@ -47,6 +49,7 @@ from pynguin.utils.generic.genericaccessibleobject import (
     GenericFunction,
     GenericMethod,
 )
+from pynguin.utils.statistics.runtimevariable import RuntimeVariable
 from pynguin.utils.type_utils import (
     COLLECTIONS,
     PRIMITIVES,
@@ -101,6 +104,7 @@ MODULE_BLACKLIST: tuple[str, ...] = (
 class _ParseResult(NamedTuple):
     """A data wrapper for an imported and parsed module."""
 
+    linenos: int
     module_name: str
     module: ModuleType
     syntax_tree: ast.AST | None
@@ -209,8 +213,9 @@ def parse_module(
 
     try:
         source_file = inspect.getsourcefile(module)
+        source_code = inspect.getsource(module)
         syntax_tree = ast.parse(
-            inspect.getsource(module),
+            source_code,
             filename=source_file if source_file is not None else "",
             type_comments=type_inference is not TypeInferenceStrategy.NONE,
             feature_version=sys.version_info[1],
@@ -226,13 +231,16 @@ def parse_module(
         annotation_replacer = _ArgumentReturnAnnotationReplacementVisitor()
         annotation_replacer.visit(syntax_tree)
         syntax_tree = ast.fix_missing_locations(syntax_tree)
+        linenos = len(source_code.splitlines())
     except OSError as error:
         LOGGER.warning(
             f"Could not retrieve source code for module {module_name} ({error}). "
             f"Cannot derive syntax tree to allow Pynguin using more precise analysis."
         )
         syntax_tree = None
+        linenos = -1
     return _ParseResult(
+        linenos=linenos,
         module_name=module_name,
         module=module,
         syntax_tree=syntax_tree,
@@ -247,7 +255,8 @@ class ModuleTestCluster:
     dependencies.
     """
 
-    def __init__(self) -> None:
+    def __init__(self, linenos: int) -> None:
+        self.__linenos = linenos
         self.__generators: dict[type, OrderedSet[GenericAccessibleObject]] = {}
         self.__modifiers: dict[type, OrderedSet[GenericAccessibleObject]] = {}
         self.__accessible_objects_under_test: OrderedSet[
@@ -257,6 +266,15 @@ class ModuleTestCluster:
             GenericAccessibleObject, _CallableData
         ] = {}
 
+    @property
+    def linenos(self) -> int:
+        """Provide the number of source code lines.
+
+        Returns:
+            The number of source code lines
+        """
+        return self.__linenos
+
     def add_generator(self, generator: GenericAccessibleObject) -> None:
         """Add the given accessible as a generator.
 
@@ -435,6 +453,45 @@ class ModuleTestCluster:
             return None
         return select_from
 
+    def track_statistics_values(
+        self, tracking_fun: Callable[[RuntimeVariable, Any], None]
+    ) -> None:
+        """Track statistics values from the test cluster and its items.
+
+        Args:
+            tracking_fun: The tracking function as a callback.
+        """
+        tracking_fun(
+            RuntimeVariable.AccessibleObjectsUnderTest,
+            self.num_accessible_objects_under_test(),
+        )
+        tracking_fun(
+            RuntimeVariable.GeneratableTypes, len(self.get_all_generatable_types())
+        )
+
+        cyclomatic_complexity = self.__compute_cyclomatic_complexities(
+            self.function_data_for_accessibles.values()
+        )
+        tracking_fun(RuntimeVariable.McCabeMin, cyclomatic_complexity.min)
+        tracking_fun(RuntimeVariable.McCabeMean, cyclomatic_complexity.mean)
+        tracking_fun(RuntimeVariable.McCabeMedian, cyclomatic_complexity.median)
+        tracking_fun(RuntimeVariable.McCabeMax, cyclomatic_complexity.max)
+        tracking_fun(RuntimeVariable.LineNos, self.__linenos)
+
+    CyclomaticComplexity = namedtuple("CyclomaticComplexity", "min mean median max")
+
+    @staticmethod
+    def __compute_cyclomatic_complexities(
+        callable_data: typing.Iterable[_CallableData],
+    ) -> CyclomaticComplexity:
+        complexities = [item.cyclomatic_complexity for item in callable_data]
+        return ModuleTestCluster.CyclomaticComplexity(
+            min=min(complexities),
+            mean=mean(complexities),
+            median=median(complexities),
+            max=max(complexities),
+        )
+
 
 class FilteredModuleTestCluster(ModuleTestCluster):
     """A test cluster wrapping another test cluster.
@@ -451,7 +508,7 @@ class FilteredModuleTestCluster(ModuleTestCluster):
         known_data: KnownData,
         targets: OrderedSet[ff.TestCaseFitnessFunction],
     ) -> None:
-        super().__init__()
+        super().__init__(linenos=delegate.linenos)
         self.__delegate = delegate
         self.__known_data = known_data
         self.__code_object_id_to_accessible_objects: dict[
@@ -578,11 +635,21 @@ def __get_class_node_from_ast(tree: ast.AST | None, name: str) -> ast.ClassDef |
 
 
 def __get_function_description_from_ast(
-    tree: ast.AST | None,
+    tree: ASTFunctionNodes | None,
 ) -> FunctionDescription | None:
     if tree is None:
         return None
-    description = get_function_descriptions(tree)
+
+    def filter_for_tree_defining_function_name(desc: FunctionDescription) -> bool:
+        return getattr(tree, "name", None) == desc.name
+
+    # Filter the resulting function descriptions for the one represented by the `tree`
+    # AST node.  There might be more than one function description, e.g., for nested
+    # functions, where we are still only interested in the top-level functions and
+    # not in the closures.
+    description = list(
+        filter(filter_for_tree_defining_function_name, get_function_descriptions(tree))
+    )
     assert len(description) == 1
     return description[0]
 
@@ -896,7 +963,7 @@ def analyse_module(parsed_module: _ParseResult) -> ModuleTestCluster:
     Returns:
         A test cluster for the module
     """
-    test_cluster = ModuleTestCluster()
+    test_cluster = ModuleTestCluster(linenos=parsed_module.linenos)
 
     for func_name, func in inspect.getmembers(
         parsed_module.module, function_in_module(parsed_module.module_name)
