@@ -7,7 +7,7 @@
 """Provides an abstract observer that can be used to generate assertions."""
 import copy
 from types import ModuleType
-from typing import List, Optional, cast
+from typing import Sized, cast
 
 import pynguin.assertion.assertion as ass
 import pynguin.assertion.assertion_trace as at
@@ -20,6 +20,7 @@ from pynguin.testcase.execution import ExecutionContext
 from pynguin.utils.type_utils import (
     is_assertable,
     is_collection_type,
+    is_ignorable_type,
     is_primitive_type,
 )
 
@@ -30,7 +31,7 @@ class AssertionTraceObserver(ex.ExecutionObserver):
 
     def __init__(self) -> None:
         self._trace: at.AssertionTrace = at.AssertionTrace()
-        self._watch_list: List[vr.VariableReference] = []
+        self._watch_list: list[vr.VariableReference] = []
 
     def clear(self) -> None:
         """Clear the existing gathered trace."""
@@ -59,9 +60,16 @@ class AssertionTraceObserver(ex.ExecutionObserver):
         self,
         statement: st.Statement,
         exec_ctx: ex.ExecutionContext,
-        exception: Optional[Exception] = None,
+        exception: Exception | None = None,
     ) -> None:
         if exception is not None:
+            self._trace.add_entry(
+                statement.get_position(),
+                ass.ExceptionAssertion(
+                    module=type(exception).__module__,
+                    exception_type_name=type(exception).__name__,
+                ),
+            )
             return
         if statement.affects_assertions:
             stmt = cast(st.VariableCreatingStatement, statement)
@@ -114,7 +122,11 @@ class AssertionTraceObserver(ex.ExecutionObserver):
         for seen_type in [
             type(exec_ctx.get_reference_value(ref)) for ref in self._watch_list
         ]:
-            if is_primitive_type(seen_type) or is_collection_type(seen_type):
+            if (
+                is_primitive_type(seen_type)
+                or is_collection_type(seen_type)
+                or is_ignorable_type(seen_type)
+            ):
                 continue
 
             if not hasattr(seen_type, "__dict__"):
@@ -157,7 +169,7 @@ class AssertionTraceObserver(ex.ExecutionObserver):
             self._trace.add_entry(
                 position, ass.ObjectAssertion(ref, copy.deepcopy(value))
             )
-        elif hasattr(value, "__len__"):
+        elif isinstance(value, Sized):
             self._trace.add_entry(
                 position, ass.CollectionLengthAssertion(ref, len(value))
             )
