@@ -11,17 +11,14 @@ import abc
 import logging
 import math
 from abc import ABCMeta, abstractmethod
-from typing import TYPE_CHECKING, Any, Generic, Tuple, TypeVar, cast, get_args
+from typing import TYPE_CHECKING, Any, Generic, TypeVar, cast, get_args
 
 from ordered_set import OrderedSet
 
 import pynguin.configuration as config
 import pynguin.testcase.variablereference as vr
 import pynguin.utils.generic.genericaccessibleobject as gao
-from pynguin.analyses.seeding.constantseeding import (
-    dynamic_constant_seeding,
-    static_constant_seeding,
-)
+from pynguin.analyses import constants
 from pynguin.utils import randomness
 from pynguin.utils.mutation_utils import alpha_exponent_insertion
 from pynguin.utils.type_utils import is_assignable_to, is_optional_parameter
@@ -29,7 +26,7 @@ from pynguin.utils.type_utils import is_assignable_to, is_optional_parameter
 if TYPE_CHECKING:
     import pynguin.assertion.assertion as ass
     import pynguin.testcase.testcase as tc
-    from pynguin.typeinference.strategy import InferredSignature
+    from pynguin.analyses.types import InferredSignature
 
 T = TypeVar("T")  # pylint:disable=invalid-name
 
@@ -180,7 +177,7 @@ class Statement(metaclass=ABCMeta):
         Returns:
             A set of assertions
         """
-        copy = OrderedSet()
+        copy: OrderedSet[ass.Assertion] = OrderedSet()
         for assertion in self._assertions:
             copy.add(assertion.clone(memo))
         return copy
@@ -723,7 +720,7 @@ class TupleStatement(NonDictCollection):
 
 
 class DictStatement(
-    CollectionStatement[Tuple[vr.VariableReference, vr.VariableReference]]
+    CollectionStatement[tuple[vr.VariableReference, vr.VariableReference]]
 ):
     """Represents a dict. The tuples represent key-value pairs."""
 
@@ -967,6 +964,15 @@ class ParametrizedStatement(
     def args(self, args: dict[str, vr.VariableReference]):
         self._args = args
 
+    @property
+    def raised_exceptions(self) -> set[str]:
+        """Provides the set of exceptions raised by this call.
+
+        Returns:
+            The set of exceptions that can be raised by this call
+        """
+        return self._generic_callable.raised_exceptions
+
     def get_variable_references(self) -> set[vr.VariableReference]:
         references = set()
         references.add(self.ret_val)
@@ -1373,9 +1379,11 @@ class PrimitiveStatement(Generic[T], VariableCreatingStatement):
         test_case: tc.TestCase,
         variable_type: type | None,
         value: T | None = None,
+        constant_provider: constants.ConstantProvider | None = None,
     ) -> None:
         super().__init__(test_case, vr.VariableReference(test_case, variable_type))
         self._value = value
+        self._constant_provider: constants.ConstantProvider | None = constant_provider
         if value is None:
             self.randomize_value()
 
@@ -1450,29 +1458,23 @@ class PrimitiveStatement(Generic[T], VariableCreatingStatement):
 class IntPrimitiveStatement(PrimitiveStatement[int]):
     """Primitive Statement that creates an int."""
 
-    def __init__(self, test_case: tc.TestCase, value: int | None = None) -> None:
-        super().__init__(test_case, int, value)
+    def __init__(
+        self,
+        test_case: tc.TestCase,
+        value: int | None = None,
+        constant_provider: constants.ConstantProvider | None = None,
+    ) -> None:
+        super().__init__(test_case, int, value, constant_provider=constant_provider)
 
     def randomize_value(self) -> None:
-        use_seed = (
-            randomness.next_float()
-            <= config.configuration.seeding.seeded_primitives_reuse_probability
-        )
         if (
-            config.configuration.seeding.dynamic_constant_seeding
-            and dynamic_constant_seeding.has_ints
-            and use_seed
-            and config.configuration.seeding.constant_seeding
+            self._constant_provider
             and randomness.next_float()
-            <= config.configuration.seeding.seeded_dynamic_values_reuse_probability
+            <= config.configuration.seeding.seeded_primitives_reuse_probability
+            and (seeded_value := self._constant_provider.get_constant_for(int))
+            is not None
         ):
-            self._value = dynamic_constant_seeding.random_int
-        elif (
-            config.configuration.seeding.constant_seeding
-            and static_constant_seeding.has_ints
-            and use_seed
-        ):
-            self._value = static_constant_seeding.random_int
+            self._value = seeded_value
         else:
             self._value = int(
                 randomness.next_gaussian() * config.configuration.test_creation.max_int
@@ -1490,7 +1492,9 @@ class IntPrimitiveStatement(PrimitiveStatement[int]):
         test_case: tc.TestCase,
         memo: dict[vr.VariableReference, vr.VariableReference],
     ) -> IntPrimitiveStatement:
-        return IntPrimitiveStatement(test_case, self._value)
+        return IntPrimitiveStatement(
+            test_case, self._value, constant_provider=self._constant_provider
+        )
 
     def __repr__(self) -> str:
         return f"IntPrimitiveStatement({self._test_case}, {self._value})"
@@ -1505,29 +1509,23 @@ class IntPrimitiveStatement(PrimitiveStatement[int]):
 class FloatPrimitiveStatement(PrimitiveStatement[float]):
     """Primitive Statement that creates a float."""
 
-    def __init__(self, test_case: tc.TestCase, value: float | None = None) -> None:
-        super().__init__(test_case, float, value)
+    def __init__(
+        self,
+        test_case: tc.TestCase,
+        value: float | None = None,
+        constant_provider: constants.ConstantProvider | None = None,
+    ) -> None:
+        super().__init__(test_case, float, value, constant_provider=constant_provider)
 
     def randomize_value(self) -> None:
-        use_seed = (
-            randomness.next_float()
-            <= config.configuration.seeding.seeded_primitives_reuse_probability
-        )
         if (
-            config.configuration.seeding.dynamic_constant_seeding
-            and dynamic_constant_seeding.has_floats
-            and use_seed
-            and config.configuration.seeding.constant_seeding
+            self._constant_provider
             and randomness.next_float()
-            <= config.configuration.seeding.seeded_dynamic_values_reuse_probability
+            <= config.configuration.seeding.seeded_primitives_reuse_probability
+            and (seeded_value := self._constant_provider.get_constant_for(float))
+            is not None
         ):
-            self._value = dynamic_constant_seeding.random_float
-        elif (
-            config.configuration.seeding.constant_seeding
-            and static_constant_seeding.has_floats
-            and use_seed
-        ):
-            self._value = static_constant_seeding.random_float
+            self._value = seeded_value
         else:
             val = (
                 randomness.next_gaussian() * config.configuration.test_creation.max_int
@@ -1553,7 +1551,9 @@ class FloatPrimitiveStatement(PrimitiveStatement[float]):
         test_case: tc.TestCase,
         memo: dict[vr.VariableReference, vr.VariableReference],
     ) -> FloatPrimitiveStatement:
-        return FloatPrimitiveStatement(test_case, self._value)
+        return FloatPrimitiveStatement(
+            test_case, self._value, constant_provider=self._constant_provider
+        )
 
     def __repr__(self) -> str:
         return f"FloatPrimitiveStatement({self._test_case}, {self._value})"
@@ -1568,29 +1568,23 @@ class FloatPrimitiveStatement(PrimitiveStatement[float]):
 class StringPrimitiveStatement(PrimitiveStatement[str]):
     """Primitive Statement that creates a String."""
 
-    def __init__(self, test_case: tc.TestCase, value: str | None = None) -> None:
-        super().__init__(test_case, str, value)
+    def __init__(
+        self,
+        test_case: tc.TestCase,
+        value: str | None = None,
+        constant_provider: constants.ConstantProvider | None = None,
+    ) -> None:
+        super().__init__(test_case, str, value, constant_provider=constant_provider)
 
     def randomize_value(self) -> None:
-        use_seed = (
-            randomness.next_float()
-            <= config.configuration.seeding.seeded_primitives_reuse_probability
-        )
         if (
-            config.configuration.seeding.dynamic_constant_seeding
-            and dynamic_constant_seeding.has_strings
-            and use_seed
-            and config.configuration.seeding.constant_seeding
+            self._constant_provider
             and randomness.next_float()
-            <= config.configuration.seeding.seeded_dynamic_values_reuse_probability
+            <= config.configuration.seeding.seeded_primitives_reuse_probability
+            and (seeded_value := self._constant_provider.get_constant_for(str))
+            is not None
         ):
-            self._value = dynamic_constant_seeding.random_string
-        elif (
-            config.configuration.seeding.constant_seeding
-            and static_constant_seeding.has_strings
-            and use_seed
-        ):
-            self._value = static_constant_seeding.random_string
+            self._value = seeded_value
         else:
             length = randomness.next_int(
                 0, config.configuration.test_creation.string_length + 1
@@ -1645,7 +1639,9 @@ class StringPrimitiveStatement(PrimitiveStatement[str]):
         test_case: tc.TestCase,
         memo: dict[vr.VariableReference, vr.VariableReference],
     ) -> StringPrimitiveStatement:
-        return StringPrimitiveStatement(test_case, self._value)
+        return StringPrimitiveStatement(
+            test_case, self._value, constant_provider=self._constant_provider
+        )
 
     def __repr__(self) -> str:
         return f"StringPrimitiveStatement({self._test_case}, {self._value})"
@@ -1660,14 +1656,28 @@ class StringPrimitiveStatement(PrimitiveStatement[str]):
 class BytesPrimitiveStatement(PrimitiveStatement[bytes]):
     """Primitive Statement that creates bytes."""
 
-    def __init__(self, test_case: tc.TestCase, value: bytes | None = None) -> None:
-        super().__init__(test_case, bytes, value)
+    def __init__(
+        self,
+        test_case: tc.TestCase,
+        value: bytes | None = None,
+        constant_provider: constants.ConstantProvider | None = None,
+    ) -> None:
+        super().__init__(test_case, bytes, value, constant_provider=constant_provider)
 
     def randomize_value(self) -> None:
-        length = randomness.next_int(
-            0, config.configuration.test_creation.bytes_length + 1
-        )
-        self._value = randomness.next_bytes(length)
+        if (
+            self._constant_provider
+            and randomness.next_float()
+            <= config.configuration.seeding.seeded_primitives_reuse_probability
+            and (seeded_value := self._constant_provider.get_constant_for(bytes))
+            is not None
+        ):
+            self._value = seeded_value
+        else:
+            length = randomness.next_int(
+                0, config.configuration.test_creation.bytes_length + 1
+            )
+            self._value = randomness.next_bytes(length)
 
     def delta(self) -> None:
         assert self._value is not None
@@ -1717,7 +1727,9 @@ class BytesPrimitiveStatement(PrimitiveStatement[bytes]):
         test_case: tc.TestCase,
         memo: dict[vr.VariableReference, vr.VariableReference],
     ) -> BytesPrimitiveStatement:
-        return BytesPrimitiveStatement(test_case, self._value)
+        return BytesPrimitiveStatement(
+            test_case, self._value, constant_provider=self._constant_provider
+        )
 
     def __repr__(self) -> str:
         return f"BytesPrimitiveStatement({self._test_case}, {self._value!r})"
